@@ -28,11 +28,13 @@ class BaselineOnly(AlgoBase):
 
         AlgoBase.__init__(self, bsl_options=bsl_options)
 
-    def train(self, trainset):
+    def fit(self, trainset):
 
-        AlgoBase.train(self, trainset)
+        AlgoBase.fit(self, trainset)
         self.bu, self.bi = self.compute_baselines()
 
+        return self
+
     def estimate(self, u, i):
 
         est = self.trainset.global_mean
